@@ -2,25 +2,10 @@
  *
  * Copyright (C) 2016 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU General Public License Version 2
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0+
  */
 
-#ifndef __GS_APP_LIST_PRIVATE_H
-#define __GS_APP_LIST_PRIVATE_H
+#pragma once
 
 #include "gs-app-list.h"
 
@@ -87,7 +72,3 @@ AsAppState	 gs_app_list_get_state		(GsAppList	*list);
 guint		 gs_app_list_get_progress	(GsAppList	*list);
 
 G_END_DECLS
-
-#endif /* __GS_APP_LIST_PRIVATE_H */
-
-/* vim: set noexpandtab: */
