@@ -26,6 +26,10 @@ gs_appstream_create_app (GsPlugin *plugin, XbSilo *silo, XbNode *component, GErr
 				      error))
 		return NULL;
 
+	/* never add wildcard apps to the plugin cache */
+	if (gs_app_has_quirk (app_new, GS_APP_QUIRK_IS_WILDCARD))
+		return g_steal_pointer (&app_new);
+
 	/* look for existing object */
 	app = gs_plugin_cache_lookup (plugin, gs_app_get_unique_id (app_new));
 	if (app != NULL)
@@ -556,6 +560,20 @@ _gs_utils_locale_has_translations (const gchar *locale)
 	return TRUE;
 }
 
+static gchar *
+_gs_utils_get_language_from_locale (const gchar *locale)
+{
+	gchar *separator;
+
+	separator = strpbrk (locale, "._");
+
+	if (separator == NULL)
+		return NULL;
+
+	return g_strndup (locale, separator - locale);
+}
+
+
 static gboolean
 gs_appstream_origin_valid (const gchar *origin)
 {
@@ -707,11 +725,16 @@ gs_appstream_refine_app (GsPlugin *plugin,
 		gs_app_set_id (app, tmp);
 
 	/* set source */
-	tmp = xb_node_query_text (component, "info/filename", NULL);
+	tmp = xb_node_query_text (component, "../info/filename", NULL);
 	if (tmp != NULL && gs_app_get_metadata_item (app, "appstream::source-file") == NULL) {
 		gs_app_set_metadata (app, "appstream::source-file", tmp);
 	}
 
+	/* set scope */
+	tmp = xb_node_query_text (component, "../info/scope", NULL);
+	if (tmp != NULL)
+		gs_app_set_scope (app, as_app_scope_from_string (tmp));
+
 	/* set content rating */
 	if (refine_flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_CONTENT_RATING) {
 		if (!gs_appstream_refine_app_content_ratings (plugin, app, component, error))
@@ -720,8 +743,13 @@ gs_appstream_refine_app (GsPlugin *plugin,
 
 	/* set name */
 	tmp = xb_node_query_text (component, "name", NULL);
-	if (tmp != NULL)
+	if (tmp != NULL) {
 		gs_app_set_name (app, GS_APP_QUALITY_HIGHEST, tmp);
+	} else {
+		/* this is a heuristic, but works even with old-style AppStream
+		 * files without the merge attribute */
+		gs_app_add_quirk (app, GS_APP_QUIRK_IS_WILDCARD);
+	}
 
 	/* set summary */
 	tmp = xb_node_query_text (component, "summary", NULL);
@@ -865,7 +893,6 @@ gs_appstream_refine_app (GsPlugin *plugin,
 					gs_app_add_source (app, tmp);
 			}
 			gs_app_set_bundle_kind (app, AS_BUNDLE_KIND_PACKAGE);
-			gs_app_set_scope (app, AS_APP_SCOPE_SYSTEM);
 		}
 	}
 
@@ -903,9 +930,18 @@ gs_appstream_refine_app (GsPlugin *plugin,
 		if (!_gs_utils_locale_has_translations (tmp)) {
 			gs_app_add_kudo (app, GS_APP_KUDO_MY_LANGUAGE);
 		} else {
-			g_autofree gchar *xpath = NULL;
-			xpath = g_strdup_printf ("languages/lang[text()='%s'][@percentage>50]", tmp);
-			if (xb_node_query_text (component, xpath, NULL) != NULL)
+
+			g_autoptr(GString) xpath = g_string_new (NULL);
+			g_autofree gchar *language = NULL;
+
+			xb_string_append_union (xpath, "languages/lang[text()='%s'][@percentage>50]", tmp);
+
+			language = _gs_utils_get_language_from_locale (tmp);
+			if (language != NULL) {
+				xb_string_append_union (xpath, "languages/lang[text()='%s'][@percentage>50]", language);
+			}
+
+			if (xb_node_query_text (component, xpath->str, NULL) != NULL)
 				gs_app_add_kudo (app, GS_APP_KUDO_MY_LANGUAGE);
 		}
 
@@ -924,7 +960,7 @@ gs_appstream_refine_app (GsPlugin *plugin,
 		/* add a kudo to featured and popular apps */
 		if (xb_node_query_text (component, "kudos/kudo[text()='GnomeSoftware::popular']", NULL) != NULL)
 			gs_app_add_kudo (app, GS_APP_KUDO_FEATURED_RECOMMENDED);
-		if (xb_node_query_text (component, "categories/category[text()='featured']", NULL) != NULL)
+		if (xb_node_query_text (component, "categories/category[text()='Featured']", NULL) != NULL)
 			gs_app_add_kudo (app, GS_APP_KUDO_FEATURED_RECOMMENDED);
 
 		/* add new-style kudos */
@@ -1010,7 +1046,7 @@ gs_appstream_silo_search_component2 (GPtrArray *array, XbNode *component, const
 }
 
 static guint16
-gs_appstream_silo_search_component (GPtrArray *array, XbNode *component, gchar **search)
+gs_appstream_silo_search_component (GPtrArray *array, XbNode *component, const gchar * const *search)
 {
 	guint16 matches_sum = 0;
 
@@ -1027,7 +1063,7 @@ gs_appstream_silo_search_component (GPtrArray *array, XbNode *component, gchar *
 gboolean
 gs_appstream_search (GsPlugin *plugin,
 		     XbSilo *silo,
-		     gchar **values,
+		     const gchar * const *values,
 		     GsAppList *list,
 		     GCancellable *cancellable,
 		     GError **error)
@@ -1036,7 +1072,7 @@ gs_appstream_search (GsPlugin *plugin,
 	g_autoptr(GPtrArray) array = g_ptr_array_new_with_free_func ((GDestroyNotify) gs_appstream_search_helper_free);
 	g_autoptr(GPtrArray) components = NULL;
 	g_autoptr(GTimer) timer = g_timer_new ();
-	struct {
+	const struct {
 		AsAppSearchMatch	 match_value;
 		const gchar		*xpath;
 	} queries[] = {
@@ -1046,6 +1082,7 @@ gs_appstream_search (GsPlugin *plugin,
 		{ AS_APP_SEARCH_MATCH_NAME,	"name[text()~=stem(?)]" },
 		{ AS_APP_SEARCH_MATCH_KEYWORD,	"keywords/keyword[text()~=stem(?)]" },
 		{ AS_APP_SEARCH_MATCH_ID,	"id[text()~=stem(?)]" },
+		{ AS_APP_SEARCH_MATCH_ID,	"launchable[text()~=stem(?)]" },
 		{ AS_APP_SEARCH_MATCH_ORIGIN,	"../components[@origin~=stem(?)]" },
 		{ AS_APP_SEARCH_MATCH_NONE,	NULL }
 	};
@@ -1081,6 +1118,11 @@ gs_appstream_search (GsPlugin *plugin,
 			g_autoptr(GsApp) app = gs_appstream_create_app (plugin, silo, component, error);
 			if (app == NULL)
 				return FALSE;
+			if (gs_app_has_quirk (app, GS_APP_QUIRK_IS_WILDCARD)) {
+				g_debug ("not returning wildcard %s",
+					 gs_app_get_unique_id (app));
+				continue;
+			}
 			g_debug ("add %s", gs_app_get_unique_id (app));
 			gs_app_set_match_value (app, match_value);
 			gs_app_list_add (list, app);
@@ -1137,11 +1179,11 @@ gs_appstream_add_category_apps (GsPlugin *plugin,
 		for (guint i = 0; i < components->len; i++) {
 			XbNode *component = g_ptr_array_index (components, i);
 			g_autoptr(GsApp) app = NULL;
-
-			/* add all the data we can */
-			app = gs_appstream_create_app (plugin, silo, component, error);
-			if (app == NULL)
-				return FALSE;
+			const gchar *id = xb_node_query_text (component, "id", NULL);
+			if (id == NULL)
+				continue;
+			app = gs_app_new (id);
+			gs_app_add_quirk (app, GS_APP_QUIRK_IS_WILDCARD);
 			gs_app_list_add (list, app);
 		}
 
@@ -1158,13 +1200,19 @@ gs_appstream_count_component_for_groups (GsPlugin *plugin, XbSilo *silo, const g
 	g_autoptr(GPtrArray) array = NULL;
 	g_autoptr(GError) error_local = NULL;
 
-	if (g_strv_length (split) != 2)
+	if (g_strv_length (split) == 1) { /* "all" group for a parent category */
+		xpath = g_strdup_printf ("components/component/categories/"
+					 "category[text()='%s']/../..",
+					 split[0]);
+	} else if (g_strv_length (split) == 2) {
+		xpath = g_strdup_printf ("components/component/categories/"
+					 "category[text()='%s']/../"
+					 "category[text()='%s']/../..",
+					 split[0], split[1]);
+	} else {
 		return 0;
+	}
 
-	xpath = g_strdup_printf ("components/component/categories/"
-				 "category[text()='%s']/../"
-				 "category[text()='%s']/../..",
-				 split[0], split[1]);
 	array = xb_silo_query (silo, xpath, limit, &error_local);
 	if (array == NULL) {
 		if (g_error_matches (error_local, G_IO_ERROR, G_IO_ERROR_NOT_FOUND))
@@ -1181,10 +1229,10 @@ gs_appstream_count_component_for_groups (GsPlugin *plugin, XbSilo *silo, const g
  * applications available in each category */
 gboolean
 gs_appstream_add_categories (GsPlugin *plugin,
-				  XbSilo *silo,
-				  GPtrArray *list,
-				  GCancellable *cancellable,
-				  GError **error)
+			     XbSilo *silo,
+			     GPtrArray *list,
+			     GCancellable *cancellable,
+			     GError **error)
 {
 	for (guint j = 0; j < list->len; j++) {
 		GsCategory *parent = GS_CATEGORY (g_ptr_array_index (list, j));
@@ -1193,14 +1241,16 @@ gs_appstream_add_categories (GsPlugin *plugin,
 		for (guint i = 0; i < children->len; i++) {
 			GsCategory *cat = g_ptr_array_index (children, i);
 			GPtrArray *groups = gs_category_get_desktop_groups (cat);
-			if (g_strcmp0 (gs_category_get_id (cat), "all") == 0)
-				continue;
 			for (guint k = 0; k < groups->len; k++) {
 				const gchar *group = g_ptr_array_index (groups, k);
 				guint cnt = gs_appstream_count_component_for_groups (plugin, silo, group);
 				for (guint l = 0; l < cnt; l++) {
 					gs_category_increment_size (parent);
-					gs_category_increment_size (cat);
+					if (children->len > 1) {
+						/* Parent category has multiple groups, so increment
+						 * each group's size too */
+						gs_category_increment_size (cat);
+					}
 				}
 			}
 		}
@@ -1294,6 +1344,10 @@ gs_appstream_add_alternates (GsPlugin *plugin,
 	g_autoptr(GPtrArray) ids = NULL;
 	g_autoptr(GString) xpath = g_string_new (NULL);
 
+	/* probably a package we know nothing about */
+	if (gs_app_get_id (app) == NULL)
+		return TRUE;
+
 	/* actual ID */
 	xb_string_append_union (xpath, "components/component/id[text()='%s']",
 				gs_app_get_id (app));
