@@ -33,7 +33,7 @@ typedef enum {
 	GS_CONTENT_RATING_SYSTEM_LAST
 } GsContentRatingSystem;
 
-const gchar *gs_utils_content_rating_age_to_str (GsContentRatingSystem system,
+gchar *gs_utils_content_rating_age_to_str (GsContentRatingSystem system,
 						 guint age);
 GsContentRatingSystem gs_utils_content_rating_system_from_locale (const gchar *locale);
 const gchar *gs_content_rating_key_value_to_str (const gchar *id,
