@@ -89,9 +89,9 @@ row_unrevealed (GObject *row, GParamSpec *pspec, gpointer data)
 static void
 gs_installed_page_unreveal_row (GsAppRow *app_row)
 {
-	gs_app_row_unreveal (app_row);
 	g_signal_connect (app_row, "unrevealed",
 			  G_CALLBACK (row_unrevealed), NULL);
+	gs_app_row_unreveal (app_row);
 }
 
 static void
@@ -172,7 +172,7 @@ gs_installed_page_add_app (GsInstalledPage *self, GsAppList *list, GsApp *app)
 	GtkWidget *app_row;
 
 	app_row = gs_app_row_new (app);
-	gs_app_row_set_show_folders (GS_APP_ROW (app_row), TRUE);
+	gs_app_row_set_show_folders (GS_APP_ROW (app_row), FALSE);
 	gs_app_row_set_show_buttons (GS_APP_ROW (app_row), TRUE);
 	if (gs_utils_list_has_app_fuzzy (list, app))
 		gs_app_row_set_show_source (GS_APP_ROW (app_row), TRUE);
