@@ -22,8 +22,6 @@
 
 #define N_TILES					9
 #define FEATURED_ROTATE_TIME			30 /* seconds */
-#define FEATURED_SWITCHER_ACTIVE_TEXT		"●"
-#define FEATURED_SWITCHER_INACTIVE_TEXT		"○"
 
 typedef struct
 {
@@ -48,7 +46,8 @@ typedef struct
 	GtkWidget		*infobar_third_party;
 	GtkWidget		*label_third_party;
 	GtkWidget		*stack_featured;
-	GtkWidget		*box_featured_switcher;
+	GtkWidget		*button_featured_back;
+	GtkWidget		*button_featured_forwards;
 	GtkWidget		*box_overview;
 	GtkWidget		*box_popular;
 	GtkWidget		*box_popular_rotating;
@@ -56,15 +55,10 @@ typedef struct
 	GtkWidget		*featured_heading;
 	GtkWidget		*category_heading;
 	GtkWidget		*flowbox_categories;
-	GtkWidget		*flowbox_categories2;
 	GtkWidget		*popular_heading;
 	GtkWidget		*recent_heading;
 	GtkWidget		*scrolledwindow_overview;
 	GtkWidget		*stack_overview;
-	GtkWidget		*categories_expander_button_down;
-	GtkWidget		*categories_expander_button_up;
-	GtkWidget		*categories_expander_box;
-	GtkWidget		*categories_more;
 } GsOverviewPagePrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GsOverviewPage, gs_overview_page, GS_TYPE_PAGE)
@@ -352,22 +346,19 @@ out:
 	gs_overview_page_decrement_action_cnt (self);
 }
 
-static gboolean
-gs_overview_page_featured_rotate_cb (gpointer user_data)
+static void
+_feature_banner_forward (GsOverviewPage *self)
 {
-	GsOverviewPage *self = GS_OVERVIEW_PAGE (user_data);
 	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
 	GtkWidget *visible_child;
 	GtkWidget *next_child = NULL;
-	GList *button_link;
 	GList *banner_link;
 	g_autoptr(GList) banners = NULL;
-	g_autoptr(GList) buttons = NULL;
 
 	visible_child = gtk_stack_get_visible_child (GTK_STACK (priv->stack_featured));
 	banners = gtk_container_get_children (GTK_CONTAINER (priv->stack_featured));
 	if (banners == NULL)
-		return G_SOURCE_CONTINUE;
+		return;
 
 	/* find banner after the currently visible one */
 	for (banner_link = banners; banner_link != NULL; banner_link = banner_link->next) {
@@ -379,24 +370,43 @@ gs_overview_page_featured_rotate_cb (gpointer user_data)
 		}
 	}
 	if (next_child == NULL)
-		next_child = g_list_nth_data (banners, 0);
-
+		next_child = g_list_first(banners)->data;
 	gtk_stack_set_visible_child (GTK_STACK (priv->stack_featured), next_child);
+}
 
-	/* update switcher */
-	buttons = gtk_container_get_children (GTK_CONTAINER (priv->box_featured_switcher));
-	for (banner_link = banners, button_link = buttons;
-	     banner_link != NULL && button_link != NULL;
-	     banner_link = banner_link->next, button_link = button_link->next) {
-		GtkWidget *event_box = button_link->data, *label;
+static void
+_feature_banner_back (GsOverviewPage *self)
+{
+	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
+	GtkWidget *visible_child;
+	GtkWidget *next_child = NULL;
+	GList *banner_link;
+	g_autoptr(GList) banners = NULL;
 
-		label = gtk_bin_get_child (GTK_BIN (event_box));
-		if (banner_link->data == next_child)
-			gtk_label_set_label (GTK_LABEL (label), FEATURED_SWITCHER_ACTIVE_TEXT);
-		else
-			gtk_label_set_label (GTK_LABEL (label), FEATURED_SWITCHER_INACTIVE_TEXT);
+	visible_child = gtk_stack_get_visible_child (GTK_STACK (priv->stack_featured));
+	banners = gtk_container_get_children (GTK_CONTAINER (priv->stack_featured));
+	if (banners == NULL)
+		return;
+
+	/* find banner before the currently visible one */
+	for (banner_link = banners; banner_link != NULL; banner_link = banner_link->next) {
+		GtkWidget *child = banner_link->data;
+		if (child == visible_child) {
+			if (banner_link->prev != NULL)
+				next_child = banner_link->prev->data;
+			break;
+		}
 	}
+	if (next_child == NULL)
+		next_child = g_list_last(banners)->data;
+	gtk_stack_set_visible_child (GTK_STACK (priv->stack_featured), next_child);
+}
 
+static gboolean
+gs_overview_page_featured_rotate_cb (gpointer user_data)
+{
+	GsOverviewPage *self = GS_OVERVIEW_PAGE (user_data);
+	_feature_banner_forward (self);
 	return G_SOURCE_CONTINUE;
 }
 
@@ -404,7 +414,6 @@ static void
 featured_reset_rotate_timer (GsOverviewPage *self)
 {
 	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
-
 	if (priv->featured_rotate_timer_id != 0)
 		g_source_remove (priv->featured_rotate_timer_id);
 	priv->featured_rotate_timer_id = g_timeout_add_seconds (FEATURED_ROTATE_TIME,
@@ -413,31 +422,17 @@ featured_reset_rotate_timer (GsOverviewPage *self)
 }
 
 static void
-featured_switcher_clicked (GtkWidget *event_box, GdkEventButton *event, gpointer data)
+_featured_back_clicked_cb (GsCategoryTile *tile, gpointer data)
 {
 	GsOverviewPage *self = GS_OVERVIEW_PAGE (data);
-	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
-	g_autoptr(GList) buttons = NULL;
-	g_autoptr(GList) banners = NULL;
-	GList *button_link, *banner_link;
+	_feature_banner_back (self);
+}
 
-	buttons = gtk_container_get_children (GTK_CONTAINER (priv->box_featured_switcher));
-	banners = gtk_container_get_children (GTK_CONTAINER (priv->stack_featured));
-	for (button_link = buttons, banner_link = banners;
-	     button_link != NULL && banner_link != NULL;
-	     button_link = button_link->next, banner_link = banner_link->next) {
-		GtkWidget *e = button_link->data;
-		GtkWidget *label;
-
-		label = gtk_bin_get_child (GTK_BIN (e));
-		if (e == event_box) {
-			gtk_stack_set_visible_child (GTK_STACK (priv->stack_featured), banner_link->data);
-			featured_reset_rotate_timer (self);
-			gtk_label_set_label (GTK_LABEL (label), FEATURED_SWITCHER_ACTIVE_TEXT);
-		} else {
-			gtk_label_set_label (GTK_LABEL (label), FEATURED_SWITCHER_INACTIVE_TEXT);
-		}
-	}
+static void
+_featured_forward_clicked_cb (GsCategoryTile *tile, gpointer data)
+{
+	GsOverviewPage *self = GS_OVERVIEW_PAGE (data);
+	_feature_banner_forward (self);
 }
 
 static void
@@ -462,8 +457,6 @@ gs_overview_page_get_featured_cb (GObject *source_object,
 
 	gtk_widget_hide (priv->featured_heading);
 	gs_container_remove_all (GTK_CONTAINER (priv->stack_featured));
-	gtk_widget_hide (priv->box_featured_switcher);
-	gs_container_remove_all (GTK_CONTAINER (priv->box_featured_switcher));
 	if (list == NULL) {
 		g_warning ("failed to get featured apps: %s",
 			   error->message);
@@ -483,31 +476,13 @@ gs_overview_page_get_featured_cb (GObject *source_object,
 	}
 	for (guint i = 0; i < gs_app_list_length (list); i++) {
 		GsApp *app = gs_app_list_index (list, i);
-		GtkWidget *event_box;
-		GtkWidget *label;
-		GtkWidget *tile;
-
-		tile = gs_feature_tile_new (app);
+		GtkWidget *tile = gs_feature_tile_new (app);
 		g_signal_connect (tile, "clicked",
 				  G_CALLBACK (app_tile_clicked), self);
 		gtk_container_add (GTK_CONTAINER (priv->stack_featured), tile);
-
-		event_box = gtk_event_box_new ();
-		gtk_widget_show (event_box);
-		g_signal_connect (event_box, "button_release_event",
-			  G_CALLBACK (featured_switcher_clicked), self);
-		gtk_container_add (GTK_CONTAINER (priv->box_featured_switcher), event_box);
-
-		label = gtk_label_new (i == 0 ? FEATURED_SWITCHER_ACTIVE_TEXT : FEATURED_SWITCHER_INACTIVE_TEXT);
-		gtk_style_context_add_class (gtk_widget_get_style_context (label),
-					     "switcher-label");
-		gtk_widget_show (label);
-		gtk_container_add (GTK_CONTAINER (event_box), label);
 	}
 	gtk_widget_show (priv->featured_heading);
 
-	gtk_widget_set_visible (priv->box_featured_switcher, gs_app_list_length (list) > 1);
-
 	priv->empty = FALSE;
 	featured_reset_rotate_timer (self);
 
@@ -538,7 +513,6 @@ gs_overview_page_get_categories_cb (GObject *source_object,
 	GsCategory *cat;
 	GtkFlowBox *flowbox;
 	GtkWidget *tile;
-	const guint MAX_CATS_PER_SECTION = 6;
 	guint added_cnt = 0;
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GPtrArray) list = NULL;
@@ -550,7 +524,6 @@ gs_overview_page_get_categories_cb (GObject *source_object,
 		goto out;
 	}
 	gs_container_remove_all (GTK_CONTAINER (priv->flowbox_categories));
-	gs_container_remove_all (GTK_CONTAINER (priv->flowbox_categories2));
 
 	/* add categories to the correct flowboxes, the second being hidden */
 	for (i = 0; i < list->len; i++) {
@@ -561,11 +534,7 @@ gs_overview_page_get_categories_cb (GObject *source_object,
 		g_signal_connect (tile, "clicked",
 				  G_CALLBACK (category_tile_clicked), self);
 		gs_category_tile_set_colorful (GS_CATEGORY_TILE (tile), TRUE);
-		if (added_cnt < MAX_CATS_PER_SECTION) {
-			flowbox = GTK_FLOW_BOX (priv->flowbox_categories);
-		} else {
-			flowbox = GTK_FLOW_BOX (priv->flowbox_categories2);
-		}
+		flowbox = GTK_FLOW_BOX (priv->flowbox_categories);
 		gtk_flow_box_insert (flowbox, tile, -1);
 		gtk_widget_set_can_focus (gtk_widget_get_parent (tile), FALSE);
 		added_cnt++;
@@ -576,9 +545,6 @@ gs_overview_page_get_categories_cb (GObject *source_object,
 				     g_object_ref (cat));
 	}
 
-	/* show the expander if we have too many children */
-	gtk_widget_set_visible (priv->categories_expander_box,
-				added_cnt > MAX_CATS_PER_SECTION);
 out:
 	if (added_cnt > 0)
 		priv->empty = FALSE;
@@ -896,10 +862,6 @@ gs_overview_page_switch_to (GsPage *page, gboolean scroll_up)
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "menu_button"));
 	gtk_widget_show (widget);
 
-	/* hide the expander */
-	gtk_revealer_set_transition_duration (GTK_REVEALER (priv->categories_more), 0);
-	gtk_revealer_set_reveal_child (GTK_REVEALER (priv->categories_more), FALSE);
-
 	if (scroll_up) {
 		adj = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (priv->scrolledwindow_overview));
 		gtk_adjustment_set_value (adj, gtk_adjustment_get_lower (adj));
@@ -912,36 +874,6 @@ gs_overview_page_switch_to (GsPage *page, gboolean scroll_up)
 	gs_overview_page_load (self);
 }
 
-static void
-categories_more_revealer_changed_cb (GtkRevealer *revealer,
-				     GParamSpec *pspec,
-				     GsOverviewPage *self)
-{
-	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
-	gboolean child_revealed = gtk_revealer_get_child_revealed (revealer);
-
-	gtk_widget_set_visible (priv->categories_expander_button_up,
-				child_revealed);
-	gtk_widget_set_visible (priv->categories_expander_button_down,
-				!child_revealed);
-}
-
-static void
-gs_overview_page_categories_expander_down_cb (GtkButton *button, GsOverviewPage *self)
-{
-	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
-	gtk_revealer_set_transition_duration (GTK_REVEALER (priv->categories_more), 250);
-	gtk_revealer_set_reveal_child (GTK_REVEALER (priv->categories_more), TRUE);
-}
-
-static void
-gs_overview_page_categories_expander_up_cb (GtkButton *button, GsOverviewPage *self)
-{
-	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
-	gtk_revealer_set_transition_duration (GTK_REVEALER (priv->categories_more), 250);
-	gtk_revealer_set_reveal_child (GTK_REVEALER (priv->categories_more), FALSE);
-}
-
 static void
 third_party_response_cb (GtkInfoBar *info_bar,
                          gint response_id,
@@ -1030,11 +962,6 @@ gs_overview_page_setup (GsPage *page,
 		gtk_container_add (GTK_CONTAINER (priv->box_recent), tile);
 	}
 
-	/* handle category expander */
-	g_signal_connect (priv->categories_expander_button_down, "clicked",
-			  G_CALLBACK (gs_overview_page_categories_expander_down_cb), self);
-	g_signal_connect (priv->categories_expander_button_up, "clicked",
-			  G_CALLBACK (gs_overview_page_categories_expander_up_cb), self);
 	return TRUE;
 }
 
@@ -1043,11 +970,13 @@ gs_overview_page_init (GsOverviewPage *self)
 {
 	GsOverviewPagePrivate *priv = gs_overview_page_get_instance_private (self);
 	gtk_widget_init_template (GTK_WIDGET (self));
+
+	g_signal_connect (priv->button_featured_back, "clicked",
+			  G_CALLBACK (_featured_back_clicked_cb), self);
+	g_signal_connect (priv->button_featured_forwards, "clicked",
+			  G_CALLBACK (_featured_forward_clicked_cb), self);
+
 	priv->settings = g_settings_new ("org.gnome.software");
-	gtk_revealer_set_transition_duration (GTK_REVEALER (priv->categories_more), 250);
-	g_signal_connect (priv->categories_more, "notify::child-revealed",
-			  G_CALLBACK (categories_more_revealer_changed_cb),
-			  self);
 }
 
 static void
@@ -1109,7 +1038,8 @@ gs_overview_page_class_init (GsOverviewPageClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, infobar_third_party);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, label_third_party);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, stack_featured);
-	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_featured_switcher);
+	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, button_featured_back);
+	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, button_featured_forwards);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_overview);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_popular);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_popular_rotating);
@@ -1117,15 +1047,10 @@ gs_overview_page_class_init (GsOverviewPageClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, category_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, featured_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, flowbox_categories);
-	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, flowbox_categories2);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, popular_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, recent_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, scrolledwindow_overview);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, stack_overview);
-	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, categories_expander_button_down);
-	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, categories_expander_button_up);
-	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, categories_expander_box);
-	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, categories_more);
 }
 
 GsOverviewPage *
